==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/assets/inc/names.php <==
<?php
session_start();
//include "tzone.php"; // include timezone

require('ldapConnect.php');

if (isset($_GET['macAddress'])) {
	$q = urldecode($_GET['macAddress']);
	$sr = ldap_search($ds,"cn=modules","(&(objectclass=*)(serialnumber=00-07-d9-$q))", array('serialnumber')); 
	$info = ldap_get_entries($ds,$sr);
	echo $info['count'];
	exit;
}

if (isset($_GET['deviceName'])) {
	$q = urldecode($_GET['deviceName']);
	$sr = ldap_search($ds,"cn=modules","(&(objectclass=Phone)(|(cn=$q)(cn=SIP $q)))", array('cn')); 
	$info = ldap_get_entries($ds,$sr);
	echo $info['count'];
	exit;
}

//get the q parameter from URL
if (isset($_GET["user"])) {
	$q = urldecode($_GET["user"]); $cns = "cn=users"; $obj = "(objectclass=user)"; $sess="user_name";
} elseif (isset($_GET["user_ext"])) {
	$q = urldecode($_GET["user_ext"]); $cns = "cn=users"; $obj = "(objectclass=user)"; $sess="user_ext";
}elseif (isset($_GET["dept"])) {
	$q = urldecode($_GET["dept"]); $cns = "cn=departments"; $obj = "(objectclass=department)"; $sess="dept_name";
}elseif (isset($_GET["dept_ext"])) {
	$q = urldecode($_GET["dept_ext"]); $cns = "cn=departments"; $obj = "(objectclass=department)"; $sess="dept_ext";
}elseif (isset($_GET["group"])) {
	$q = urldecode($_GET["group"]); $cns = "cn=groups"; $obj = "(objectclass=group)"; $sess="group_name";
}elseif (isset($_GET["timeplan"])) {
	$q = urldecode($_GET["timeplan"]); $cns = "cn=timeplans"; $obj = "(objectclass=timeplan)"; $sess="timeplan_name";
}elseif (isset($_GET["meetmeconference"])) {
	$q = urldecode($_GET["meetmeconference"]); $cns = "cn=meetmeconferences"; $obj = "(objectclass=meetmeconference)"; $sess="meetmeconference_name";	
}elseif (isset($_GET["dialplan"])) {
	$q = urldecode($_GET["dialplan"]); $cns = "cn=dialplans"; $obj = "(objectclass=dialplan)"; $sess="dialplan_name";
}elseif (isset($_GET["lcrplan"])) {
	$q = urldecode($_GET["lcrplan"]); $cns = "cn=leastcostcallplans"; $obj = "(objectclass=leastcostcallplan)"; $sess="lcrplan_name";
}elseif (isset($_GET["sip"])) {
	$q = urldecode($_GET["sip"]); $cns = "cn=Modules"; $obj = "(objectclass=module)"; $sess="sip_names";
}elseif (isset($_GET["adn"])) {
	$q = urldecode($_GET["adn"]); $cns = "cn=system"; $obj = "(objectclass=administrator)"; $sess="admin_names";
}elseif (isset($_GET["adnpass"])) {
	$q = urldecode($_GET["adnpass"]); $sess="admin_pass";
}

// if session not set create session - if sess contains name the session = cn else session = telephonenumber
if (!isset($_SESSION[$sess])) {

if (strstr($sess,"ext")) {
	$sr=ldap_list($ds, "cn=users", "(objectclass=user)",array('telephonenumber')); $info = ldap_get_entries($ds, $sr);
	for ($m=0; $m<$info['count']; $m++) {
		$_SESSION[$sess][] = $info[$m]['telephonenumber'][0];
	}
	$sr=ldap_list($ds, "cn=departments", "(objectclass=department)",array('telephonenumber')); $info = ldap_get_entries($ds, $sr);
	for ($m=0; $m<$info['count']; $m++) {
		$_SESSION[$sess][] = $info[$m]['telephonenumber'][0];
	}
} else {

if (!isset($_GET["adnpass"])) {
$sr=ldap_list($ds, $cns, $obj,array('cn')); $info = ldap_get_entries($ds, $sr);
	for ($m=0; $m<$info['count']; $m++) {
		//echo $info[$m]['cn'][0];
		$_SESSION[$sess][] = $info[$m]['cn'][0];
	}
	 
  } else {
		$_SESSION[$sess][] = '';
  }
  
 }
}
//lookup all hints from array if length of q>0
if (strlen($q) > 0)
  {
  $hint="";
  for($i=0; $i<count($_SESSION[$sess]); $i++)
    {
    if (strtolower($q)==strtolower($_SESSION[$sess][$i]))
      {
      $hint = ($hint=="") ? $hint=$_SESSION[$sess][$i] : $hint=$hint." , ".$_SESSION[$sess][$i];
      }
    }
  }
$bch = array("\"","\,","!","\'","%","^",":","~","#","|","@",".",";","`","\\","/","*","$","\t","="); $chars = preg_quote(implode('', $bch)); $url = $_SERVER['SERVER_ADDR'];
if (preg_match('-['.$chars.']-', $q)) {
  //$response = "<strong style='color: red;'>&nbsp;$q&nbsp;</strong>invalid&nbsp;<img src='images/error.jpg'>";
  $response = "error";
  } elseif (@$hint =="") {
  //$response="<strong style='color: green;'>&nbsp;$q&nbsp;</strong>available&nbsp;<img src='images/ok.jpg'>";
  $response = "ok";
  } else {
  //$response="<strong style='color: red;'>&nbsp;$hint&nbsp;</strong>unavailable&nbsp;<img src='images/error.jpg'>";
  $response = "error";
  }
//output the response
echo stripslashes($response);
session_destroy();
?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/assets/inc/names.php <==
<?php
session_start();
//include "tzone.php"; // include timezone

require('ldapConnect.php');

if (isset($_GET['macAddress'])) {
	$q = urldecode($_GET['macAddress']);
	$sr = ldap_search($ds,"cn=modules","(&(objectclass=*)(serialnumber=00-07-d9-$q))", array('serialnumber')); 
	$info = ldap_get_entries($ds,$sr);
	echo $info['count'];
	exit;
}

if (isset($_GET['deviceName'])) {
	$q = urldecode($_GET['deviceName']);
	$sr = ldap_search($ds,"cn=modules","(&(objectclass=Phone)(|(cn=$q)(cn=SIP $q)))", array('cn')); 
	$info = ldap_get_entries($ds,$sr);
	echo $info['count'];
	exit;
}

//get the q parameter from URL
if (isset($_GET["user"])) {
	$q = urldecode($_GET["user"]); $cns = "cn=users"; $obj = "(objectclass=user)"; $sess="user_name";
} elseif (isset($_GET["user_ext"])) {
	$q = urldecode($_GET["user_ext"]); $cns = "cn=users"; $obj = "(objectclass=user)"; $sess="user_ext";
}elseif (isset($_GET["dept"])) {
	$q = urldecode($_GET["dept"]); $cns = "cn=departments"; $obj = "(objectclass=department)"; $sess="dept_name";
}elseif (isset($_GET["dept_ext"])) {
	$q = urldecode($_GET["dept_ext"]); $cns = "cn=departments"; $obj = "(objectclass=department)"; $sess="dept_ext";
}elseif (isset($_GET["group"])) {
	$q = urldecode($_GET["group"]); $cns = "cn=groups"; $obj = "(objectclass=group)"; $sess="group_name";
}elseif (isset($_GET["timeplan"])) {
	$q = urldecode($_GET["timeplan"]); $cns = "cn=timeplans"; $obj = "(objectclass=timeplan)"; $sess="timeplan_name";
}elseif (isset($_GET["meetmeconference"])) {
	$q = urldecode($_GET["meetmeconference"]); $cns = "cn=meetmeconferences"; $obj = "(objectclass=meetmeconference)"; $sess="meetmeconference_name";	
}elseif (isset($_GET["dialplan"])) {
	$q = urldecode($_GET["dialplan"]); $cns = "cn=dialplans"; $obj = "(objectclass=dialplan)"; $sess="dialplan_name";
}elseif (isset($_GET["lcrplan"])) {
	$q = urldecode($_GET["lcrplan"]); $cns = "cn=leastcostcallplans"; $obj = "(objectclass=leastcostcallplan)"; $sess="lcrplan_name";
}elseif (isset($_GET["sip"])) {
	$q = urldecode($_GET["sip"]); $cns = "cn=Modules"; $obj = "(objectclass=module)"; $sess="sip_names";
}elseif (isset($_GET["adn"])) {
	$q = urldecode($_GET["adn"]); $cns = "cn=system"; $obj = "(objectclass=administrator)"; $sess="admin_names";
}elseif (isset($_GET["adnpass"])) {
	$q = urldecode($_GET["adnpass"]); $sess="admin_pass";
}

// if session not set create session - if sess contains name the session = cn else session = telephonenumber
if (!isset($_SESSION[$sess])) {

if (strstr($sess,"ext")) {
	$sr=ldap_list($ds, "cn=users", "(objectclass=user)",array('telephonenumber')); $info = ldap_get_entries($ds, $sr);
	for ($m=0; $m<$info['count']; $m++) {
		$_SESSION[$sess][] = $info[$m]['telephonenumber'][0];
	}
	$sr=ldap_list($ds, "cn=departments", "(objectclass=department)",array('telephonenumber')); $info = ldap_get_entries($ds, $sr);
	for ($m=0; $m<$info['count']; $m++) {
		$_SESSION[$sess][] = $info[$m]['telephonenumber'][0];
	}
} else {

if (!isset($_GET["adnpass"])) {
$sr=ldap_list($ds, $cns, $obj,array('cn')); $info = ldap_get_entries($ds, $sr);
	for ($m=0; $m<$info['count']; $m++) {
		//echo $info[$m]['cn'][0];
		$_SESSION[$sess][] = $info[$m]['cn'][0];
	}
	 
  } else {
		$_SESSION[$sess][] = '';
  }
  
 }
}
//lookup all hints from array if length of q>0
if (strlen($q) > 0)
  {
  $hint="";
  for($i=0; $i<count($_SESSION[$sess]); $i++)
    {
    if (strtolower($q)==strtolower($_SESSION[$sess][$i]))
      {
      $hint = ($hint=="") ? $hint=$_SESSION[$sess][$i] : $hint=$hint." , ".$_SESSION[$sess][$i];
      }
    }
  }
$bch = array("\"","\,","!","%","^",":","~","#","|","@",".",";","`","\\","/","*","$","\t","="); $chars = preg_quote(implode('', $bch)); $url = $_SERVER['SERVER_ADDR'];
if (preg_match('-['.$chars.']-', $q)) {
  //$response = "<strong style='color: red;'>&nbsp;$q&nbsp;</strong>invalid&nbsp;<img src='images/error.jpg'>";
  $response = "error";
  } elseif (@$hint =="") {
  //$response="<strong style='color: green;'>&nbsp;$q&nbsp;</strong>available&nbsp;<img src='images/ok.jpg'>";
  $response = "ok";
  } else {
  //$response="<strong style='color: red;'>&nbsp;$hint&nbsp;</strong>unavailable&nbsp;<img src='images/error.jpg'>";
  $response = "error";
  }
//output the response
echo stripslashes($response);
session_destroy();
?>
